# django-glue
We built Django Glue to help solve the problem of fluid interactions between the front and back ends of a Django application.
Our end goal is to bring as much front end power to the Django framework as possible while remaining pythonic.

This project is in prototype phase please look at the tests directory of this code base for examples and instructions.

## Why?
We are active web platform developers that want to provide our clients with the best user experience without having to learn a bunch of different technology stacks.
Django glue allows us to do fancy javascript like page interactions and updates while remaining in the comfort of our django/python world.

Education is also a big part of what we do and our focus is on teaching our people python, so they can focus on data science and automation and make solid interfaces! 

## Inspiration
We are inspired by how quickly django's model structure, ORM and forms (crispy forms) allow you to create functional web applications.
Can we build on top of 25+ years of development to create a front end tool that uses the power of django.

## Forms


## Requirements
- Django 3.2+ or 4.0+
- Python 3.8+

## Dependencies
- Alpine JS
- Bootstrap 5
- Axios

## Documentation
- Installation Guide - [Here](INSTALLATION.md)
- Usage Guide - [Here](USAGE.md)

## Roadmap
### April 2024
- [ ] Review project architecture for dependency flow and extendability
- [ ] Includes for Alpine Js & Bootstrap
- [ ] Basic form field elements


### May 2024
- [ ] Working with form fields that are not glued
- [ ] Creating your own form elements

## Authors
- Nathan Johnson
- Wesley Howery
- Austin Sauer